diff --git a/lib/SimpleSAML/Bindings/Shib13/Artifact.php b/lib/SimpleSAML/Bindings/Shib13/Artifact.php
index 649d7905cac7016771a0fff90e6a549f9efb4cf7..5f5ce01f5e7a769ec1dc58b14b609fbb8ea4a2c7 100644
--- a/lib/SimpleSAML/Bindings/Shib13/Artifact.php
+++ b/lib/SimpleSAML/Bindings/Shib13/Artifact.php
@@ -137,9 +137,9 @@ class SimpleSAML_Bindings_Shib13_Artifact {
 				"-----END CERTIFICATE-----\n";
 		}
 
-		$file = SimpleSAML_Utils_System::getTempDir() . DIRECTORY_SEPARATOR . sha1($certData) . '.crt';
+		$file = SimpleSAML\Utils\System::getTempDir() . DIRECTORY_SEPARATOR . sha1($certData) . '.crt';
 		if (!file_exists($file)) {
-			SimpleSAML_Utils_System::writeFile($file, $certData);
+            SimpleSAML\Utils\System::writeFile($file, $certData);
 		}
 
 		$spKeyCertFile = SimpleSAML_Utilities::resolveCert($spMetadata->getString('privatekey'));
diff --git a/lib/SimpleSAML/Logger/LoggingHandlerSyslog.php b/lib/SimpleSAML/Logger/LoggingHandlerSyslog.php
index 04c3711acd2520242ba4e98c6bd93ed13d7b40ec..6b8abef9d3f835e14f99ad7ff28f3d07a7ab9dd6 100644
--- a/lib/SimpleSAML/Logger/LoggingHandlerSyslog.php
+++ b/lib/SimpleSAML/Logger/LoggingHandlerSyslog.php
@@ -27,7 +27,7 @@ class SimpleSAML_Logger_LoggingHandlerSyslog implements SimpleSAML_Logger_Loggin
         $processname = $config->getString('logging.processname', 'simpleSAMLphp');
 
         // Setting facility to LOG_USER (only valid in Windows), enable log level rewrite on windows systems.
-        if (SimpleSAML_Utils_System::getOS() === SimpleSAML_Utils_System::WINDOWS) {
+        if (SimpleSAML\Utils\System::getOS() === SimpleSAML\Utils\System::WINDOWS) {
             $this->isWindows = TRUE;
             $facility = LOG_USER;
         }
diff --git a/lib/SimpleSAML/Utils/System.php b/lib/SimpleSAML/Utils/System.php
index bce9285cd1eb408c9e562c4caf58a8bd5b759e2c..8b2b3ed1d650922da4abfd3dcc9c108fd2df3ff5 100644
--- a/lib/SimpleSAML/Utils/System.php
+++ b/lib/SimpleSAML/Utils/System.php
@@ -1,12 +1,12 @@
 <?php
-
+namespace SimpleSAML\Utils;
 
 /**
  * System-related utility methods.
  *
  * @package SimpleSAMLphp
  */
-class SimpleSAML_Utils_System
+class System
 {
 
     const WINDOWS = 1;
diff --git a/modules/metarefresh/lib/MetaLoader.php b/modules/metarefresh/lib/MetaLoader.php
index f9393ebc674474dc62bc5ee10cd935e3ad330d21..e8d869677b00622025ea36aac0f91e4e960f6a42 100644
--- a/modules/metarefresh/lib/MetaLoader.php
+++ b/modules/metarefresh/lib/MetaLoader.php
@@ -238,7 +238,7 @@ class sspmod_metarefresh_MetaLoader {
 	public function writeState() {
 		if($this->changed) {
 			SimpleSAML_Logger::debug('Writing: ' . $this->stateFile);
-            SimpleSAML_Utils_System::writeFile(
+            SimpleSAML\Utils\System::writeFile(
 				$this->stateFile,
 				"<?php\n/* This file was generated by the metarefresh module at ".$this->getTime() . ".\n".
 				" Do not update it manually as it will get overwritten. */\n".
@@ -393,7 +393,7 @@ class sspmod_metarefresh_MetaLoader {
 
 				$content .= "\n" . '?>';
 
-				SimpleSAML_Utils_System::writeFile($filename, $content, 0644);
+                SimpleSAML\Utils\System::writeFile($filename, $content, 0644);
 			} elseif(is_file($filename)) {
 				if(unlink($filename)) {
 					SimpleSAML_Logger::debug('Deleting stale metadata file: ' . $filename);
diff --git a/lib/SimpleSAML/Utilities.php b/lib/SimpleSAML/Utilities.php
index 92b2fda3cfd240b797bad9163006ca51bac64075..247019e4bf5aeb7e1644edb385feee3ad250e509 100644
--- a/lib/SimpleSAML/Utilities.php
+++ b/lib/SimpleSAML/Utilities.php
@@ -1321,18 +1321,18 @@ class SimpleSAML_Utilities {
 	}
 
 	/**
 	 * @deprecated This method will be removed in SSP 2.0. Please use SimpleSAML_Utils_System::writeFile() instead.
 	 */
 	public static function writeFile($filename, $data, $mode=0600) {
-		return SimpleSAML_Utils_System::writeFile($filename, $data, $mode);
+		return SimpleSAML\Utils\System::writeFile($filename, $data, $mode);
 	}
 
 
 	/**
 	 * @deprecated This method will be removed in SSP 2.0. Please use SimpleSAML_Utils_System::getTempDir instead.
 	 */
 	public static function getTempDir() {
-		return SimpleSAML_Utils_System::getTempDir();
+		return SimpleSAML\Utils\System::getTempDir();
 	}
 
 
@@ -1587,10 +1587,10 @@ class SimpleSAML_Utilities {
 
 
 	/**
 	 * @deprecated This method will be removed in SSP 2.0. Please use SimpleSAML_Utils_System::getOS() instead.
 	 */
 	public static function isWindowsOS() {
-		return SimpleSAML_Utils_System::getOS() === SimpleSAML_Utils_System::WINDOWS;
+		return SimpleSAML\Utils\System::getOS() === SimpleSAML\Utils\System::WINDOWS;
 	}
 
 
@@ -1321,18 +1321,18 @@ class SimpleSAML_Utilities {
 
 	/**
-	 * @deprecated This method will be removed in SSP 2.0. Please use SimpleSAML_Utils_System::writeFile() instead.
+	 * @deprecated This method will be removed in SSP 2.0. Please use SimpleSAML\Utils\System::writeFile() instead.
 	 */
 	public static function writeFile($filename, $data, $mode=0600) {
@@ -1321,18 +1321,18 @@ class SimpleSAML_Utilities {
 
 	/**
-	 * @deprecated This method will be removed in SSP 2.0. Please use SimpleSAML_Utils_System::getTempDir instead.
+	 * @deprecated This method will be removed in SSP 2.0. Please use SimpleSAML\Utils\System::getTempDir instead.
 	 */
 	public static function getTempDir() {
@@ -1587,10 +1587,10 @@ class SimpleSAML_Utilities {
 
 	/**
-	 * @deprecated This method will be removed in SSP 2.0. Please use SimpleSAML_Utils_System::getOS() instead.
+	 * @deprecated This method will be removed in SSP 2.0. Please use SimpleSAML\Utils\System::getOS() instead.
 	 */
 	public static function isWindowsOS() {